@@ -13,8 +13,8 @@ def main():
 
     required.add_argument('-Oo','--originRepoOwner', type=str, required=True, help="De GitHub naam van de lector")
     required.add_argument('-Or','--originRepo', type=str, required=True, help="De repo waar de opdracht staat")
-    required.add_argument('-Do','--destinationRepoOwner', type=str, required=True, help="Uw GitHub naam")
-    required.add_argument('-Dr','--destinationRepo', type=str, required=True, help="Uw repository naam test")
+    required.add_argument('-Do','--destinationRepoOwner', type=str, required=True, help="De naam van de GitHub classroom")
+    required.add_argument('-Dr','--destinationRepo', type=str, required=True, help="Uw repository naam in de classroom (waarschijnlijk opdracht-uwGitHubNaam)")
 
     args = parser.parse_args()
 
