@@ -26,7 +26,7 @@ def main():
         dict.append({
             "title": issue["title"],
             "body": issue["body"],
-            "lables": issue["labels"]
+            "labels": issue["labels"]
             })
     with open(args.file,"w+") as file:
         yaml.dump(dict,file)
